Struct hypers_core::prelude::RustlsConfig
source · pub struct RustlsConfig {
pub key: Vec<u8>,
pub cert: Vec<u8>,
pub ocsp: Vec<u8>,
pub client_auth: ClientAuth,
}Expand description
rustls’s config.
Fields
key: Vec<u8>Private key.
cert: Vec<u8>Certificate.
ocsp: Vec<u8>OCSP response.
client_auth: ClientAuthImplementations
sourceimpl RustlsConfig
impl RustlsConfig
sourcepub fn client_auth_optional(self, trust_anchor: Vec<u8>) -> Self
pub fn client_auth_optional(self, trust_anchor: Vec<u8>) -> Self
Sets the trust anchor for optional Tls client authentication
sourcepub fn client_auth_required(self, trust_anchor: Vec<u8>) -> Self
pub fn client_auth_required(self, trust_anchor: Vec<u8>) -> Self
Sets the trust anchor for required Tls client authentication
sourcepub fn build(self) -> Result<ServerConfig, Error>
pub fn build(self) -> Result<ServerConfig, Error>
builds the Tls ServerConfig